aboutsummaryrefslogtreecommitdiff
path: root/src/args.rs
diff options
context:
space:
mode:
Diffstat (limited to 'src/args.rs')
-rw-r--r--src/args.rs6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/args.rs b/src/args.rs
index 52d7ae8..d064370 100644
--- a/src/args.rs
+++ b/src/args.rs
@@ -28,9 +28,9 @@ pub struct Args {
#[arg(short = 's', long = "stats", action = ArgAction::SetTrue)]
pub stats: bool,
- /// Print the legende line
- #[arg(short = 'l', long = "legende", action = ArgAction::SetTrue)]
- pub legende: bool,
+ /// Print the legend line
+ #[arg(short = 'l', long = "legend", action = ArgAction::SetTrue)]
+ pub legend: bool,
/// Print the status line, the given target and the IP the ping is send to.
#[arg(short = 'S', long = "status", action = ArgAction::SetTrue)]